RaknetServer

Struct RaknetServer 

pub struct RaknetServer { /* private fields */ }

Implementations

Source

impl RaknetServer

pub fn builder() -> RaknetServerBuilder

Creates a default builder.

pub async fn bind(bind_addr: SocketAddr) -> Result<Self>

Starts server with default configs and provided bind address.

pub fn facade(&mut self) -> ServerFacade<'_>

Creates closure-based facade over server event stream.

pub fn event_facade<'a, H: EventFacadeHandler>( &'a mut self, handler: &'a mut H, ) -> EventFacade<'a, H>

Creates trait-based event facade over server event stream.

pub fn session_facade<'a, H: SessionFacadeHandler>( &'a mut self, handler: &'a mut H, ) -> SessionFacade<'a, H>

Creates session-id based facade over server event stream.

pub async fn start_with_configs( transport_config: TransportConfig, runtime_config: ShardedRuntimeConfig, ) -> Result<Self>

Starts server from explicit transport and runtime configurations.

pub fn peer_addr(&self, peer_id: PeerId) -> Option<SocketAddr>

Returns peer socket address for a peer id, if present.

pub fn peer_shard(&self, peer_id: PeerId) -> Option<usize>

Returns shard id owning a peer, if present.

pub fn peer_id_for_addr(&self, addr: SocketAddr) -> Option<PeerId>

Resolves peer id by remote address, if known.

pub async fn send( &self, peer_id: PeerId, payload: impl Into<Bytes>, ) -> Result<()>

Sends payload with default send options.

pub async fn send_with_options( &self, peer_id: PeerId, payload: impl Into<Bytes>, options: SendOptions, ) -> Result<()>

Sends payload with explicit send options.

pub async fn send_with_receipt( &self, peer_id: PeerId, payload: impl Into<Bytes>, receipt_id: u64, ) -> Result<()>

Sends payload and tracks a receipt id.

pub async fn send_with_options_and_receipt( &self, peer_id: PeerId, payload: impl Into<Bytes>, options: SendOptions, receipt_id: u64, ) -> Result<()>

Sends payload with explicit send options and receipt id.

pub async fn disconnect(&mut self, peer_id: PeerId) -> Result<()>

Requests disconnection and emits a local disconnect event.

pub async fn next_event(&mut self) -> Option<RaknetServerEvent>

Polls next server event.

Returns None when runtime event channel is closed.

pub async fn shutdown(self) -> Result<()>

Gracefully stops all workers and closes sockets.