SessionIdAdapter

Struct SessionIdAdapter 

pub struct SessionIdAdapter { /* private fields */ }
Bidirectional mapping between PeerId and stable session ids.

Implementations

Source

impl SessionIdAdapter

pub fn new() -> Self

Creates a new empty adapter.

pub fn len(&self) -> usize

Returns number of currently mapped sessions.

pub fn is_empty(&self) -> bool

Returns true if no session is currently mapped.

pub fn session_id_for_peer(&self, peer_id: PeerId) -> Option<SessionId>

Resolves a PeerId to session id.

pub fn peer_id_for_session(&self, session_id: SessionId) -> Option<PeerId>

Resolves a session id to PeerId.

pub fn peer_id_for_session_i32(&self, session_id: i32) -> Option<PeerId>

Resolves an i32 session id to PeerId.

pub fn register_peer(&mut self, peer_id: PeerId) -> Result<SessionId>

Registers peer and returns mapped session id.

If peer is already registered, existing id is returned.

pub fn unregister_peer(&mut self, peer_id: PeerId) -> Option<SessionId>

Unregisters peer and returns removed session id, if present.

pub fn clear(&mut self)

Clears all mappings and resets id allocator.

pub fn session_id_to_i32(session_id: SessionId) -> Option<i32>

Converts internal session id to i32 when representable.

pub fn session_id_from_i32(session_id: i32) -> Option<SessionId>

Converts i32 session id into internal type.